@@ -1,4 +1,4 @@
-/* SCTP kernel reference Implementation
+/* SCTP kernel Implementation
  * Copyright (c) 2003 Hewlett-Packard Development Company, L.P
  * (C) Copyright IBM Corp. 2004
  *
@@ -13,13 +13,13 @@
  * TEST7: Reading the pending message socket that received SHUTDOWN
  * TEST8: No more message and association is shutdown
  *
- * The SCTP reference implementation is free software;
+ * The SCTP implementation is free software;
  * you can redistribute it and/or modify it under the terms of
  * the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
  *
- * The SCTP reference implementation is distributed in the hope that it
+ * The SCTP implementation is distributed in the hope that it
  * will be useful, but WITHOUT ANY WARRANTY; without even the implied
  *                 ************************
  * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
@@ -64,11 +64,12 @@ int TST_CNT = 0;
 int
 main(int argc, char *argv[])
 {
-        int ret,len;
+        socklen_t len;
+	int ret;
 	int sk,pf_class,lstn_sk,acpt_sk;
 	int flag = 0;
 	struct msghdr inmessage;
-        u_int8_t *message = "hello, world!\n";
+        char *message = "hello, world!\n";
 	struct iovec iov_rcv;
         int count;
 	char * buffer_rcv;
